# gatoniel-utils

[![Build Status](https://github.com/gatoniel/gatoniel-utils/workflows/test/badge.svg?branch=master&event=push)](https://github.com/gatoniel/gatoniel-utils/actions?query=workflow%3Atest)
[![codecov](https://codecov.io/gh/gatoniel/gatoniel-utils/branch/master/graph/badge.svg)](https://codecov.io/gh/gatoniel/gatoniel-utils)
[![Python Version](https://img.shields.io/pypi/pyversions/gatoniel-utils.svg)](https://pypi.org/project/gatoniel-utils/)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)

Library with utils and helpers for myself.


## Features

- Fully typed with annotations and checked with mypy, [PEP561 compatible](https://www.python.org/dev/peps/pep-0561/)
- Add yours!


## Installation

```bash
pip install gatoniel-utils
```


## Example

Showcase how your project can be used:

```python
from gatoniel_utils.example import some_function

print(some_function(3, 4))
# => 7
```

## License

[MIT](https://github.com/gatoniel/gatoniel-utils/blob/master/LICENSE)


## Credits

This project was generated with [`wemake-python-package`](https://github.com/wemake-services/wemake-python-package). Current template version is: [0c5619079cb74e7dc72e1f18e9176b3b3a1a843f](https://github.com/wemake-services/wemake-python-package/tree/0c5619079cb74e7dc72e1f18e9176b3b3a1a843f). See what is [updated](https://github.com/wemake-services/wemake-python-package/compare/0c5619079cb74e7dc72e1f18e9176b3b3a1a843f...master) since then.
